@@ -1,6 +1,6 @@
 #!/bin/sh
 
-crldump.py <<EOT
+python crldump.py <<EOT
 -----BEGIN X509 CRL-----
 MIIBVjCBwAIBATANBgkqhkiG9w0BAQUFADB+MQswCQYDVQQGEwJBVTETMBEGA1UE
 CBMKU29tZS1TdGF0ZTEhMB8GA1UEChMYSW50ZXJuZXQgV2lkZ2l0cyBQdHkgTHRk
